 .. _benchmarks:

==========
Benchmarks
==========

In this section, we measure the running times of the implementations of several graph kernels from *GraKeL* and we compare them to each other and to implementations from other packages.

  .. toctree::
    :maxdepth: 1

    benchmarks/comparison
    benchmarks/evaluation